==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/el.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Έρευνα χρήσης",
    "Sent on: {on}" : "Αποστέλλεται σε: {on}",
    "An error occurred while sending your report." : "Παρουσιάστηκε σφάλμα κατά την αποστολή της αναφοράς σας.",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Λίστα εφαρμογών<em>(Για κάθε εφαρμογή: όνομα, έκδοση, είναι ενεργοποιημένη;)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Περιβάλλον βάσης δεδομένων <em>(Τύπος, έκδοση, μέγεθος βάσης δεδομένων) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Πληροφορίες κρυπτογράφησης <em>(είναι ενεργοποιημένες; , ποιό είναι το προεπιλεγμένο άρθρωμα) </em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Αριθμός διαμοιρασμών<em>(ανά τύπο και ρύθμιση δικαιωμάτων)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Περιβάλλον PHP <em>(έκδοση, όριο μνήμης, μέγιστος χρόνος εκτέλεσης, μέγιστο μέγεθος αρχείου)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Λεπτομέρειες διακομιστή <em>(έκδοση, χρήση memcache, locking/previews/avatars ενεργοποιημένα;)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Στατιστικά <em>(αριθμός: αρχείων, χρηστών, μονάδων αποθήκευσης ανά τύπο, σχόλια και ετικέτες)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Θέλετε να μας βοηθήσετε να βελτιώσουμε το Nextcloud παρέχοντας κάποια ανώνυμα δεδομένα σχετικά με τις ρύθμισεις και τη χρήση; Μπορείτε να την απενεργοποιήσετε ανά πάσα στιγμή από τις ρυθμίσεις διαχειριστή ξανά.",
    "Not now" : "Όχι τώρα",
    "Send usage" : "Αποστολή χρήσης",
    "Never" : "Ποτέ",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να βοηθήσετε στη βελτίωση του Nextcloud με την αποστολή ορισμένων στοιχείων σχετικά με τις τρέχουσες ρυθμίσεις και τη χρήση.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Παίρνουμε στα σοβαρά τα προσωπικά σας δεδομένα. Η αποστολή δεδομένων είναι απενεργοποιημένη από προεπιλογή και αν επιλέξετε να την ενεργοποιήσετε, θα είναι ανώνυμη πρώτα και θα σας δοθεί η δυνατότητα τι ακριβώς θα μοιραστείτε. Μόλις ληφθεί μια αναφορά, η προηγούμενη καταργείται. Μεταφορτώστε μια καθαρή αναφορά για να διαγράψετε όλα τα δεδομένα που είναι αποθηκευμένα στο διακομιστή.",
    "Send new report now" : "Αποστολή νέας αναφοράς τώρα",
    "Send usage survey monthly" : "Αποστολή έρευνας χρήσης μηνιαία",
    "Data to send" : "Δεδομένα προς αποστολή",
    "Last report" : "Τελευταία αναφορά",
    "Sent on: %s" : "Στάλθηκε στις: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Μπορείτε να μας βοηθήσετε να βελτιώσουμε το Nextcloud με την αποστολή κάποιων δεδομένων σχετικά με την τρέχουσα εγκατάστασή σας και τη χρήση που κάνετε. ",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να μας βοηθήσετε να βελτιώσουμε το Nextcloud με την αποστολή κάποιων δεδομένων σχετικά με την τρέχουσα εγκατάστασή σας και τη χρήση που κάνετε. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/el.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Έρευνα χρήσης",
    "Last report sent on: {on}" : "Η τελευταία αναφορά στάλθηκε στις: {on}",
    "An error occurred while sending your report." : "Παρουσιάστηκε σφάλμα κατά την αποστολή της αναφοράς σας.",
    "Database environment <em>(type, version, database size)</em>" : "Περιβάλλον βάσης δεδομένων <em>(Τύπος, έκδοση, μέγεθος βάσης δεδομένων) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Πληροφορίες κρυπτογράφησης <em>(είναι ενεργοποιημένες; , ποιό είναι το προεπιλεγμένο άρθρωμα) </em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Αριθμός διαμοιρασμών<em>(ανά τύπο και ρύθμιση δικαιωμάτων)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Περιβάλλον PHP <em>(έκδοση, όριο μνήμης, μέγιστος χρόνος εκτέλεσης, μέγιστο μέγεθος αρχείου)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Στατιστικά <em>(αριθμός: αρχείων, χρηστών, μονάδων αποθήκευσης ανά τύπο, σχόλια και ετικέτες)</em>",
    "Help improve Nextcloud" : "Βοηθήστε στην βελτίωση του Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Θέλετε να μας βοηθήσετε να βελτιώσουμε το Nextcloud παρέχοντας κάποια ανώνυμα δεδομένα σχετικά με τις ρύθμισεις και τη χρήση; Μπορείτε να την απενεργοποιήσετε ανά πάσα στιγμή από τις ρυθμίσεις διαχειριστή ξανά.",
    "Not now" : "Όχι τώρα",
    "Send usage" : "Αποστολή χρήσης",
    "Never" : "Ποτέ",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να βοηθήσετε στη βελτίωση του Nextcloud με την αποστολή ορισμένων στοιχείων σχετικά με τις τρέχουσες ρυθμίσεις και τη χρήση.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Παίρνουμε στα σοβαρά τα προσωπικά σας δεδομένα. Η αποστολή δεδομένων είναι απενεργοποιημένη από προεπιλογή και αν επιλέξετε να την ενεργοποιήσετε, θα είναι ανώνυμη πρώτα και θα σας δοθεί η δυνατότητα τι ακριβώς θα μοιραστείτε. Μόλις ληφθεί μια αναφορά, η προηγούμενη καταργείται. Μεταφορτώστε μια καθαρή αναφορά για να διαγράψετε όλα τα δεδομένα που είναι αποθηκευμένα στο διακομιστή.",
    "Send new report now" : "Αποστολή νέας αναφοράς τώρα",
    "Send usage survey monthly" : "Αποστολή έρευνας χρήσης μηνιαία",
    "Data to send" : "Δεδομένα προς αποστολή",
    "Last report" : "Τελευταία αναφορά",
    "Sent on: {on}" : "Αποστέλλεται σε: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Λίστα εφαρμογών<em>(Για κάθε εφαρμογή: όνομα, έκδοση, είναι ενεργοποιημένη;)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Λεπτομέρειες διακομιστή <em>(έκδοση, χρήση memcache, locking/previews/avatars ενεργοποιημένα;)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να μας βοηθήσετε να βελτιώσουμε το Nextcloud με την αποστολή κάποιων δεδομένων σχετικά με την τρέχουσα εγκατάστασή σας και τη χρήση που κάνετε. ",
    "Sent on: %s" : "Στάλθηκε στις: %s"
},
"nplurals=2; plural=(n != 1);");
